==> EdSurvey_2.3.2.tar.gz: EdSurvey/tests/testthat/REF-6-ECLS_K.R <==

dat1Summary.Ref <- c("   childid             gender                                           race      ",
                     " Length:21357       MALE  :10927   WHITE, NON-HISPANIC                    :11788  ",
                     " Class :character   FEMALE:10430   BLACK OR AFRICAN AMERICAN, NON-HISPANIC: 3224  ",
                     " Mode  :character                  HISPANIC, RACE NOT SPECIFIED           : 1987  ",
                     "                                   HISPANIC, RACE SPECIFIED               : 1839  ",
                     "                                   ASIAN                                  : 1365  ",
                     "                                   MORE THAN ONE RACE, NON HISPANIC       :  549  ",
                     "                                   (Other)                                :  605  ")

dat2Summary.Ref <- c("   childid             c1height        c2height        c3height        c4height        c5height        c6height        c7height    ",
                     " Length:21409       Min.   :35.00   Min.   :35.00   Min.   :35.00   Min.   :35.00   Min.   :45.00   Min.   :45.00   Min.   :24.00  ",
                     " Class :character   1st Qu.:43.13   1st Qu.:44.50   1st Qu.:45.50   1st Qu.:46.76   1st Qu.:51.25   1st Qu.:55.50   1st Qu.:62.00  ",
                     " Mode  :character   Median :44.50   Median :46.00   Median :47.00   Median :48.38   Median :53.00   Median :57.50   Median :64.25  ",
                     "                    Mean   :44.64   Mean   :45.94   Mean   :46.99   Mean   :48.41   Mean   :53.05   Mean   :57.63   Mean   :64.37  ",
                     "                    3rd Qu.:46.00   3rd Qu.:47.50   3rd Qu.:48.50   3rd Qu.:50.00   3rd Qu.:54.75   3rd Qu.:59.50   3rd Qu.:66.75  ",
                     "                    Max.   :60.00   Max.   :60.00   Max.   :60.00   Max.   :60.00   Max.   :66.00   Max.   :73.00   Max.   :76.25  ",
                     "                    NA's   :2374    NA's   :1599    NA's   :16317   NA's   :5425    NA's   :7513    NA's   :10329   NA's   :12443  ")

wgt.Ref <- c("There are 71 full sample weight(s) in this edsurvey.data.frame",
             "  'c1cw0' with 90 JK replicate weights.",               
             "  'c1pw0' with 90 JK replicate weights.",
             "  'c1cptw0' with 90 JK replicate weights.",                    
             "  'c2cw0' with 90 JK replicate weights.",
             "  'c2pw0' with 90 JK replicate weights.",                
             "  'c2cptw0' with 90 JK replicate weights.",
             "  'bycw0' with 90 JK replicate weights.",              
             "  'bypw0' with 90 JK replicate weights.",
             "  'bycptw0' with 90 JK replicate weights.",      
             "  'bycomw0' with 90 JK replicate weights.",
             "  'c3cw0' with 40 JK replicate weights.",
             "  'c4cw0' with 90 JK replicate weights.",
             "  'c34cw0' with 40 JK replicate weights.",                     
             "  'c3pw0' with 40 JK replicate weights.",
             "  'c4pw0' with 90 JK replicate weights.",               
             "  'c34pw0' with 40 JK replicate weights.",
             "  'c4cptw0' with 90 JK replicate weights.",
             "  'c5cw0' with 90 JK replicate weights.",
             "  'c5pw0' with 90 JK replicate weights.",
             "  'c5cptw0' with 90 JK replicate weights.",
             "  'c6cw0' with 90 JK replicate weights.",
             "  'c6pw0' with 90 JK replicate weights.",
             "  'c23cw0' with 40 JK replicate weights.",
             "  'c123cw0' with 40 JK replicate weights.",
             "  'c24cw0' with 90 JK replicate weights.",
             "  'c124cw0' with 90 JK replicate weights.",
             "  'c1_4cw0' with 40 JK replicate weights.",
             "  'c23pw0' with 40 JK replicate weights.",
             "  'c123pw0' with 40 JK replicate weights.",
             "  'c24pw0' with 90 JK replicate weights.",
             "  'c124pw0' with 90 JK replicate weights.",
             "  'c1_4pw0' with 40 JK replicate weights.",
             "  'y2comw0' with 90 JK replicate weights.",
             "  'c245cw0' with 90 JK replicate weights.",
             "  'c45cw0' with 90 JK replicate weights.",
             "  'c1_5fc0' with 90 JK replicate weights.",
             "  'c1_5sc0' with 40 JK replicate weights.",
             "  'c245pw0' with 90 JK replicate weights.",
             "  'c45pw0' with 90 JK replicate weights.",                     
             "  'c1_5fp0' with 90 JK replicate weights.",
             "  'c1_5sp0' with 40 JK replicate weights.",
             "  'c56cw0' with 90 JK replicate weights.",
             "  'c456cw0' with 90 JK replicate weights.",
             "  'c2_6fc0' with 90 JK replicate weights.",
             "  'c1_6fc0' with 90 JK replicate weights.",
             "  'c1_6sc0' with 40 JK replicate weights.",
             "  'c56pw0' with 90 JK replicate weights.",
             "  'c456pw0' with 90 JK replicate weights.",
             "  'c2_6fp0' with 90 JK replicate weights.",
             "  'c1_6fp0' with 90 JK replicate weights.",
             "  'c1_6sp0' with 40 JK replicate weights.",
             "  'c6cptr0' with 90 JK replicate weights.",
             "  'c6cptm0' with 90 JK replicate weights.",
             "  'c6cpts0' with 90 JK replicate weights.",
             "  'c7cw0' with 90 JK replicate weights.",
             "  'c67cw0' with 90 JK replicate weights.",
             "  'c567cw0' with 90 JK replicate weights.",
             "  'c4_7cw0' with 90 JK replicate weights.",
             "  'c2_7fc0' with 90 JK replicate weights.",
             "  'c1_7fc0' with 90 JK replicate weights.",
             "  'c1_7sc0' with 40 JK replicate weights.",
             "  'c7pw0' with 90 JK replicate weights.",
             "  'c67pw0' with 90 JK replicate weights.",
             "  'c567pw0' with 90 JK replicate weights.",
             "  'c4_7pw0' with 90 JK replicate weights.",
             "  'c2_7fp0' with 90 JK replicate weights.",
             "  'c1_7fp0' with 90 JK replicate weights.",
             "  'c1_7sp0' with 40 JK replicate weights.",
             "  'c7cpte0' with 90 JK replicate weights.",
             "  'c7cptm0' with 90 JK replicate weights.",
             "  'c7cpts0' with 90 JK replicate weights." )

lmTaylorREF <- c("", "Formula: x8mscalk4 ~ x12sesl", "", "Weight variable: 'w8c28p_8t280'", 
                 "Variance method: Taylor series", "full data n: 18174", "n used: 6460", 
                 "", "Coefficients:", "                 coef        se         t    dof  Pr(>|t|)    ", 
                 "(Intercept) 110.44930   0.42864 257.67614 25.755 < 2.2e-16 ***", 
                 "x12sesl       7.37147   0.30441  24.21581 34.896 < 2.2e-16 ***",
                 "---", "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1", 
                 "", "Multiple R-squared: 0.1462", "")


ecls_sumREF <- c("Estimates are not weighted.", "  Variable     N  Min. 1st Qu. Median     Mean 3rd Qu.  Max.       SD  NA's", 
                 "1 c7r4mscl 21409 66.17  129.25 146.33 142.2209  160.18 172.2 22.00873 12124"
)

ecls_sum_wREF <- c("Estimates are weighted using weight variable 'c7cpts0'", 
                   "  Variable     N Weighted N  Min.  1st Qu.   Median     Mean  3rd Qu.  Max.       SD  NA's Zero-weights", 
                   "1 c7r4mscl 21409    3941257 66.26 125.8516 144.3048 139.9674 158.9644 172.2 23.61741 12124         5561"
)

==> EdSurvey_2.5.0.tar.gz: EdSurvey/tests/testthat/REF-6-ECLS_K.R <==

dat1Summary.Ref <- c("   childid             gender                                           race      ",
                     " Length:21357       MALE  :10927   WHITE, NON-HISPANIC                    :11788  ",
                     " Class :character   FEMALE:10430   BLACK OR AFRICAN AMERICAN, NON-HISPANIC: 3224  ",
                     " Mode  :character                  HISPANIC, RACE NOT SPECIFIED           : 1987  ",
                     "                                   HISPANIC, RACE SPECIFIED               : 1839  ",
                     "                                   ASIAN                                  : 1365  ",
                     "                                   MORE THAN ONE RACE, NON HISPANIC       :  549  ",
                     "                                   (Other)                                :  605  ")

dat2Summary.Ref <- c("   childid             c1height        c2height        c3height        c4height        c5height        c6height        c7height    ",
                     " Length:21409       Min.   :35.00   Min.   :35.00   Min.   :35.00   Min.   :35.00   Min.   :45.00   Min.   :45.00   Min.   :24.00  ",
                     " Class :character   1st Qu.:43.13   1st Qu.:44.50   1st Qu.:45.50   1st Qu.:46.76   1st Qu.:51.25   1st Qu.:55.50   1st Qu.:62.00  ",
                     " Mode  :character   Median :44.50   Median :46.00   Median :47.00   Median :48.38   Median :53.00   Median :57.50   Median :64.25  ",
                     "                    Mean   :44.64   Mean   :45.94   Mean   :46.99   Mean   :48.41   Mean   :53.05   Mean   :57.63   Mean   :64.37  ",
                     "                    3rd Qu.:46.00   3rd Qu.:47.50   3rd Qu.:48.50   3rd Qu.:50.00   3rd Qu.:54.75   3rd Qu.:59.50   3rd Qu.:66.75  ",
                     "                    Max.   :60.00   Max.   :60.00   Max.   :60.00   Max.   :60.00   Max.   :66.00   Max.   :73.00   Max.   :76.25  ",
                     "                    NA's   :2374    NA's   :1599    NA's   :16317   NA's   :5425    NA's   :7513    NA's   :10329   NA's   :12443  ")

wgt.Ref <- c("There are 71 full sample weight(s) in this edsurvey.data.frame",
             "  'c1cw0' with 90 JK replicate weights.",               
             "  'c1pw0' with 90 JK replicate weights.",
             "  'c1cptw0' with 90 JK replicate weights.",                    
             "  'c2cw0' with 90 JK replicate weights.",
             "  'c2pw0' with 90 JK replicate weights.",                
             "  'c2cptw0' with 90 JK replicate weights.",
             "  'bycw0' with 90 JK replicate weights.",              
             "  'bypw0' with 90 JK replicate weights.",
             "  'bycptw0' with 90 JK replicate weights.",      
             "  'bycomw0' with 90 JK replicate weights.",
             "  'c3cw0' with 40 JK replicate weights.",
             "  'c4cw0' with 90 JK replicate weights.",
             "  'c34cw0' with 40 JK replicate weights.",                     
             "  'c3pw0' with 40 JK replicate weights.",
             "  'c4pw0' with 90 JK replicate weights.",               
             "  'c34pw0' with 40 JK replicate weights.",
             "  'c4cptw0' with 90 JK replicate weights.",
             "  'c5cw0' with 90 JK replicate weights.",
             "  'c5pw0' with 90 JK replicate weights.",
             "  'c5cptw0' with 90 JK replicate weights.",
             "  'c6cw0' with 90 JK replicate weights.",
             "  'c6pw0' with 90 JK replicate weights.",
             "  'c23cw0' with 40 JK replicate weights.",
             "  'c123cw0' with 40 JK replicate weights.",
             "  'c24cw0' with 90 JK replicate weights.",
             "  'c124cw0' with 90 JK replicate weights.",
             "  'c1_4cw0' with 40 JK replicate weights.",
             "  'c23pw0' with 40 JK replicate weights.",
             "  'c123pw0' with 40 JK replicate weights.",
             "  'c24pw0' with 90 JK replicate weights.",
             "  'c124pw0' with 90 JK replicate weights.",
             "  'c1_4pw0' with 40 JK replicate weights.",
             "  'y2comw0' with 90 JK replicate weights.",
             "  'c245cw0' with 90 JK replicate weights.",
             "  'c45cw0' with 90 JK replicate weights.",
             "  'c1_5fc0' with 90 JK replicate weights.",
             "  'c1_5sc0' with 40 JK replicate weights.",
             "  'c245pw0' with 90 JK replicate weights.",
             "  'c45pw0' with 90 JK replicate weights.",                     
             "  'c1_5fp0' with 90 JK replicate weights.",
             "  'c1_5sp0' with 40 JK replicate weights.",
             "  'c56cw0' with 90 JK replicate weights.",
             "  'c456cw0' with 90 JK replicate weights.",
             "  'c2_6fc0' with 90 JK replicate weights.",
             "  'c1_6fc0' with 90 JK replicate weights.",
             "  'c1_6sc0' with 40 JK replicate weights.",
             "  'c56pw0' with 90 JK replicate weights.",
             "  'c456pw0' with 90 JK replicate weights.",
             "  'c2_6fp0' with 90 JK replicate weights.",
             "  'c1_6fp0' with 90 JK replicate weights.",
             "  'c1_6sp0' with 40 JK replicate weights.",
             "  'c6cptr0' with 90 JK replicate weights.",
             "  'c6cptm0' with 90 JK replicate weights.",
             "  'c6cpts0' with 90 JK replicate weights.",
             "  'c7cw0' with 90 JK replicate weights.",
             "  'c67cw0' with 90 JK replicate weights.",
             "  'c567cw0' with 90 JK replicate weights.",
             "  'c4_7cw0' with 90 JK replicate weights.",
             "  'c2_7fc0' with 90 JK replicate weights.",
             "  'c1_7fc0' with 90 JK replicate weights.",
             "  'c1_7sc0' with 40 JK replicate weights.",
             "  'c7pw0' with 90 JK replicate weights.",
             "  'c67pw0' with 90 JK replicate weights.",
             "  'c567pw0' with 90 JK replicate weights.",
             "  'c4_7pw0' with 90 JK replicate weights.",
             "  'c2_7fp0' with 90 JK replicate weights.",
             "  'c1_7fp0' with 90 JK replicate weights.",
             "  'c1_7sp0' with 40 JK replicate weights.",
             "  'c7cpte0' with 90 JK replicate weights.",
             "  'c7cptm0' with 90 JK replicate weights.",
             "  'c7cpts0' with 90 JK replicate weights." )

lmTaylorREF <- c("",
                 "Formula: x8mscalk4 ~ x12sesl",
                 "",
                 "Weight variable: 'w8c28p_8t280'", 
                 "Variance method: Taylor series",
                 "full data n: 18174",
                 "n used: 6460", 
                 "",
                 "Coefficients:",
                 "                 coef        se       t    dof  Pr(>|t|)    ", 
                 "(Intercept) 110.44930   0.42864 257.676 25.755 < 2.2e-16 ***", 
                 "x12sesl       7.37147   0.30441  24.216 34.896 < 2.2e-16 ***",
                 "---",
                 "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1", 
                 "",
                 "Multiple R-squared: 0.1462",
                 "")


ecls_sumREF <- c("Estimates are not weighted.",
                 "  Variable     N  Min. 1st Qu. Median     Mean 3rd Qu.  Max.       SD  NA's", 
                 "1 c7r4mscl 21409 66.17  129.25 146.33 142.2209  160.18 172.2 22.00873 12124")

ecls_sum_wREF <- c("Estimates are weighted using weight variable 'c7cpts0'", 
                   "  Variable     N Weighted N  Min.  1st Qu. Median     Mean  3rd Qu.  Max.       SD  NA's Zero-weights", 
                   "1 c7r4mscl 21409    3941257 66.26 125.8504  144.3 139.9674 158.9718 172.2 23.62027 12124         5561")
